@@ -19,7 +19,7 @@ Usage::
     list_revision_assets_paginator: ListRevisionAssetsPaginator = client.get_paginator("list_revision_assets")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_dataexchange.type_defs import (
     ListDataSetRevisionsResponseTypeDef,
@@ -40,33 +40,33 @@ __all__ = (
 
 class ListDataSetRevisionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDataSetRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
+    [Paginator.ListDataSetRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
     """
 
     def paginate(
         self, DataSetId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDataSetRevisionsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDataSetRevisionsResponseTypeDef]:
         """
-        [ListDataSetRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions.paginate)
+        [ListDataSetRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions.paginate)
         """
 
 
 class ListDataSetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDataSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
+    [Paginator.ListDataSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
     """
 
     def paginate(
         self, Origin: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDataSetsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDataSetsResponseTypeDef]:
         """
-        [ListDataSets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets.paginate)
+        [ListDataSets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets.paginate)
         """
 
 
 class ListJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
+    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
     """
 
     def paginate(
@@ -74,20 +74,20 @@ class ListJobsPaginator(Boto3Paginator):
         DataSetId: str = None,
         RevisionId: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListJobsResponseTypeDef]:
         """
-        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs.paginate)
+        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs.paginate)
         """
 
 
 class ListRevisionAssetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRevisionAssets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
+    [Paginator.ListRevisionAssets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
     """
 
     def paginate(
         self, DataSetId: str, RevisionId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListRevisionAssetsResponseTypeDef, None, None]:
+    ) -> Iterator[ListRevisionAssetsResponseTypeDef]:
         """
-        [ListRevisionAssets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets.paginate)
+        [ListRevisionAssets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.15/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets.paginate)
         """
